#
# spec file for package drush
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           drush
Version:        8.3.2
Release:        1.12
Summary:        Command line shell and scripting interface for Drupal
# See licenses.txt for dependency licenses.
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Servers
Url:            http://www.drush.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-vendor.tar.xz
Source10:       extensions.php
Source11:       extensions.txt
Source12:       licenses.txt
Source13:       update.sh
BuildRequires:  xz
Requires:       php >= 5.4.5
Requires:       php-ctype
# Should fallback to polyfill, but does not actually work.
Requires:       php-iconv
Requires:       php-json
Requires:       which

Suggests:       php-iconv
Suggests:       php-mbstring
Suggests:       php-pcntl
Suggests:       php-posix
Suggests:       php-readline
Suggests:       php-sqlite

Obsoletes:      drush_make < %{version}
Provides:       drush_make = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Drush is a command line shell and scripting interface for Drupal, a veritable
Swiss Army knife designed to make life easier for those of us who spend some of
our working hours hacking away at the command prompt.

%prep
# -a 1: unpack Source1 vendor tarball
%setup -q -a 1

%build
find . -name ".travis.yml" -delete
cp %{SOURCE12} licenses.txt

%install
# install drush source
install -d -m 0755 . %{buildroot}%{_datadir}/%{name}
cp -r * %{buildroot}%{_datadir}/%{name}

# link to executable in bindir
mkdir -p %{buildroot}%{_bindir}
ln -s %{_datadir}/%{name}/%{name} %{buildroot}%{_bindir}/%{name}

# link to bash complete script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
ln -s %{_datadir}/%{name}/drush.complete.sh %{buildroot}%{_sysconfdir}/bash_completion.d/

%files
%defattr(-,root,root,-)
%doc licenses.txt
%{_datadir}/%{name}
%{_bindir}/%{name}
%{_sysconfdir}/bash_completion.d/drush.complete.sh

%changelog
* Wed Nov 27 2019 jimmy@boombatower.com
- Update to version 8.3.2:
  * Prep for 8.3.2.
  * #4253: Include 'src' directory in phar builds.
  * Back to dev
* Fri Oct 25 2019 jimmy@boombatower.com
- Update to version 8.3.1:
  * Prep for 8.3.1
  * Try out Drupal 9 support (#4227)
  * Better UX in case of mixing Drupal 7 sources with Drupal 8 root (#4143)
  * Updated subscription options in README.md (#4125)
  * Back to dev
* Wed Jul 10 2019 jimmy@boombatower.com
- Update to version 8.3.0:
  * Prep for 8.3.0
  * Support wildcard aliases for Drush 8 (#4109)
  * Fix 8.x build (#4110)
  * Convert Drush Make to Composer more accurately (#4082)
  * Back to dev
  * Prep for 8.2.3
  * No timeout by default in DrushTT. (#4029)
  * Back to dev
* Tue Mar 26 2019 jimmy@boombatower.com
- Update to version 8.2.2:
  * Prep for 8.2.2
  * Drush test traits for 8.x branch (#4008)
  * Test Drupal 8.7.0-alpha1, and update exact versions tested for older minor releases of Drupal 8. (#4000)
  * Back to dev
* Thu Mar 14 2019 jimmy@boombatower.com
- Update to version 8.2.1:
  * Prep for 8.2.1
  * Fix $this being used in a static context in Drush.php. (#3994)
  * Fix backported command aliases: some that had too many ':'s should have been using '-'s instead. (#3991)
  * Fixes #3988: Move code to get version directly to the static access methods in case someone (e.g. a module) calls them directly. (#3990)
  * Update composer.lock
  * Bump minimum version of consolidation/annotated-command
  * Back to dev
* Tue Mar 12 2019 Jimmy Berry <jimmy@boombatower.com>
- Include which as runtime requirement.
* Tue Mar 12 2019 jimmy@boombatower.com
- Update to version 8.2.0:
  * Prep for 8.2.0
  * Fix up config export data to have the same structure as Drush 9 where it is possible and convenient to do so.
  * Add placeholder 'export' function to DrushConfig
  * Inject InputInterface into callback parameters
  * Fill in 'timestamp' if it is missing in logger to avoid warning
  * Add drush 9 style command aliases
  * Fix up process manager
  * Add ConfigAdapter
  * Improve process manager support
  * Add adaptors for the alias managor and the process manager. These are not included in our vendor directory by default, but can be used if they exist in the bootstrapped Drupal site. Also add UserAbortException. TODO: Catch UserAbortException
  * Drush make is no longer maintained (fixes #3946). (#3953)
  * Improve consistency of command files between Drush 9 and Drush 8: (#3928)
  * Skip Drupal 8.4.x in pmEnDisUnListInfoTest.php (fix previous commit) (#3935)
  * Skip failing test; panels has a problem with an EOL verison of Drupal. No need to fix or work around that.
  * D7: file_get_stream_wrappers cache poisoning in update_check_requirements() (#3789)
  * Drupalorg updates (#3915)
  * Revert "git:// is discontinued on drupal.org - https://twitter.com/drupal_infra/status/1088571024918994945 (#3899)"
  * git:// is discontinued on drupal.org - https://twitter.com/drupal_infra/status/1088571024918994945 (#3899)
  * Convert lint tests on 8.x branch from Circle 1 to Circle 2 (#3910)
  * Fix boolean logic check of --local option for commands (#3777)
  * Guard against bad return value in config-pull
  * Back to dev.
* Wed Nov 21 2018 jimmy@boombatower.com
- Update to version 8.1.18:
  * Prep for 8.1.18
  * Restore 91da7528, inadvertantly reverted. (#3791)
  * Add tests for Drupal 8.46 with PHP 7.
  * Only remove the fallback if the 'mysql' extension isn't available
  * Fixed that Drush always sneakily uses the mysql extension even though mysqli is configured and the extension is enabled
  * Fixes #3761. Taking into account unreadable output of 'stty size' when... (#3764)
  * Set a non-zero exit status for "sql-create" on failure (#3733)
  * Fix #2282, #2079. Do not pass this->query_extra to pg_dump. Refs #3727.
  * Remove fifth argument of error handler. (#3712)
  * Backport #3687: preserve 'contrib' and 'custom' dir placements (#3702)
  * adding drush option to core-cli so that we can change the default working directory
  * Set maintenance mode to update when running updates (#3605)
  * #2183: Mention possible conflict of ~/.my.cnf vs --defaults-extra-file (#3581)
  * fix Drush command sql-query with option "--db-prefix" in use (#3529)
  * Back to dev.
* Wed May 30 2018 jimmy@boombatower.com
- Update to version 8.1.17:
  * Prep for 8.1.17.
  * #3039 : Fixed numeric notice in PHP 7.x.
  * Fix #2285, #2268. Recognize current working dir for multisites when bootstrapping a site. Affects hosts that have pcntl_exec(). (#3550)
  * Fix PHP 7.2 warning regarding count() (#3545)
  * Fix drush make-convert --format=composer (#3499)
  * Call batch finished with call_user_func_array() to use static method call. (#3517)
  * Remove failing assertion that provides no value.
  * Remove docs that were copied from drush9 in error.
  * Change URL of feed in a test to bypass unicode SQL error. Woop woop for Goofy theme!
  * Change installation instructions to recommend cgr instead of 'composer global'. (#3471)
  * Add tests for Drupal 8.5. (#3438)
  * Prevent 'drush @local uli' and related commands from executing twice. (#3428)
  * Fix php 7.1 warning for COLUMNS env variable.
  * Stop all processing of queue on SuspendQueueException (#3327)
  * back to dev.
* Wed Feb  7 2018 jimmy@boombatower.com
- Update to version 8.1.16:
  * prep for 8.1.16.
  * Allow updatedb to proceed despite requirements errors if user confirms.
  * Updated pear/console_table package. (#3352)
  * Fix #3078. Environment variables are prepended to Drush command in the wrong order (#3361)
  * Fix #3360. Clarify that example is for Drupal 6,7 only.
  * Fixes #3351: site-install Drupal 7 with PHP 7.2 (#3353)
  * Update build rules for shippable on the 8.x branch. (#3349)
  * sql-sanitize to generate random user password (fixes #3086) (#3343)
  * Fix router.php to work with update.php (#3247)
  * Use new License identifier
  * Update pear/console_table package (#3325)
  * Backport of #3174, SSH command escaping (#3185)
  * Fix PHP 7.2 count() notices due to pear/console_table (#3292)
  * Issue #3199: Add ignored-directories option to 8.x (#3205)
  * Fix .travis.yml error: run 'composer install' before 'box build' rather than after. Note that this saves >1M from the size of the .phar.
  * Remove pin of reflection-docblock. Update to latest version of annotated-command, which no longer requires reflection-docblock. (#3157)
  * Check requirements before running updatedb (#2708)
  * Back to dev.
* Wed Oct 18 2017 jimmy@boombatower.com
- Update requires and suggests to reflect current version.
* Tue Oct 10 2017 jimmy@boombatower.com
- Update to version 8.1.15:
  * Back to dev.
  * Add skip_cleanup and remove old S3 deployments.
  * Add isolation dir to .gitignore on 8.x
  * Exclude isolation dir from the phar.
  * Backport to 8.x #2604 Allow delete of single value in a config object (#3004)
  * Allow Symfony 3 components for site-local installs of Drush 8.x (#2800)
  * Loosen constraint on symfony/yaml for site-local installs.
  * Remove useless code comment.
  * Prep for 8.1.15.
* Tue Oct  3 2017 jimmy@boombatower.com
- Update to version 8.1.14:
  * Back to dev.
  * Update install docs for planned deprecation of http://files.drush.org/drush.phar.
  * Fix serving existing files with encoded characters like `%%20`
  * Update Psysh to version 0.8.11
  * Ensure "sql-cli" command sets an error on non-zero child process exit status. (#2925)
  * Revert "Update Psysh to version 0.8.11"
  * Update psysh to 0.8.11
  * Work on #2912 - More robust path handling in FileCache.
  * Revert "Work on #2912 - More robust path handling in FileCache."
  * Work on #2912 - More robust path handling in FileCache.
  * Fixes #2767: Do not attempt to access the cached Drush commandfile services unless they exist in the container. This converts a crashing scenario into one where commands are merely missing. A 'drush cr' should bring back the missing commands.
  * prep for release.
* Tue Aug 22 2017 jimmy@boombatower.com
- Update to version 8.1.13:
  * Prep for 8.1.13-dev
  * Fix #2753: Prevent loops when unable to download extensions (#2797)
  * Fix #2817. bash autocomplete via .bashrc only works on the second .bashrc inclusion.
  * Disable the psysh version check.
  * Fixes #2831: create_function is deprecated in php 7.2; might as well use an anonymous function instead.
  * Fix drush docs, link to 8.x docs from within the 8.x documentation (#2842)
  * Add php lint operation via CircleCI.
  * Respect disable_functions list in  use_pcntl_exec check (#2857)
  * fix namespace for Drush command sql-query with option "--db-prefix" in use (#2882)
  * Just assert that disabled module's command can't be run. The actual error is not important, and seems to be variable based on phases of the moon.
  * Prep for 8.1.13.
* Sat Jul 22 2017 jimmy@boombatower.com
- Add licenses.txt to %%doc.
* Tue Jun  6 2017 jimmy@boombatower.com
- Add source references to development files.
- Update to version 8.1.12:
  * Fix image style generation for d7
  * Back to dev.
  * Adopt form changes for update notification during site installation (8.x version) (#2675)
  * Update since 8.4.x core exists now.
  * Documented local paths for patches in makefile (#2769)
  * Fix #2756 #2723 drush init causes .bashrc syntax to break
  * Workaround segmentation fault when clearing caches. (#2765)
  * Backport #2724 / f476dd51 (Sans Symfony 3) to Drush 8.x.
  * Moar testing permutations.
  * Prep for 8.1.12
* Fri Apr 21 2017 jimmy@boombatower.com
- Update to version 8.1.11:
  * Back to dev.
  * Fix #2658: Run invalidateContainer() only when needed (#2663)
  * Remove --skip-modules from cim and cex. (Backport #2684) (#2686)
  * Prep for 8.1.12
  * Issue #2709: Fixed non-reporting of config-import errors. (#2713)
  * Fix #2682 drush init breaks bashrc if there's no newline at end.
  * Deduplicate the langcode to avoid a message repetition. (#2715)
  * Issue #1854: Allow uninstall of dependent modules (8.x). (#2717)
  * Prep for 8.1.11.
* Thu Feb 23 2017 jimmy@boombatower.com
- Update to version 8.1.10:
  * Back to dev. trying a new numbering scheme which a bit is clearer when running a non-tagged release.
  * Fix spacing between badges (#2549)
  * Use config.storage.sync to instantiate the FileStorage (#2471)
  * Fixes queue-run message placeholder (#2578)
  * remove validation for the equalness of @source and @target in sql-sync
  * Remove query string processing from D8 rs bootstrap (#2599)
  * Report progress during config-import.
  * Fix issue #1314: backport to 8.x (#2602)
  * Fix #2550 Undefined index: memory Logger.php:125
  * Fixes #2617: Perform cache rebuild during updb in same process (#2621)
  * Backport #2631 (si improvements for ci) to Drush 8.x.
  * Clean the export directory via the config storage (#2638)
  * Prep for 8.1.10
* Mon Jan 16 2017 jimmy@boombatower.com
- Update to version 8.1.9:
  * back to dev.
  * Append /login to the user password reset URL also in 8.X (#2481)
  * Adapt release notes test to new date format on drupal.org
  * Adding sanitation of user Fields for Drupal 8. (#2457)
  * Don't extend a non-existent class.
  * Add back user creation during test for D6/D7.
  * Use output-formatters:~3 (#2510)
  * change filename in mysql defaults template (#2455)
  * Fix notify warning.
  * Invalid policy example.
  * change $_SERVER['REQUEST_METHOD'] default to 'GET' (#2512)
  * Add storage filter hook for benefit of config_split and similar contrib/custom projects.
  * Prep for 8.1.9
* Wed Nov 30 2016 jimmy@boombatower.com
- Update to version 8.1.8:
  * back to dev.
  * Fix #2425. archive-dump does not handle failure in gzip.
  * Issue #2426: Convert legacy translation placeholders to valid D8 placeholders (#2427)
  * Path is the only valid argument for browse command. Stop passing along others.
  * Drush 8.x version of #2433
  * Filter out placeholders that can not be cast to strings.
  * Fix error message when unable to copy example.sites.php to sites.php (#2439)
  * Add —input-format option and deprecate —format for the state-set command
  * Reorganize example shell aliases by Drupal version
  * Typo in command description.
  * Clear user caches like core/rebuild.php does. (#2450)
  * fix [warning] apcu_clear_cache() expects exactly 0 parameters, 1 given (#2451)
  * Prep for 8.1.8.
* Mon Oct 24 2016 jimmy@boombatower.com
- Update to version 8.1.7:
  * Back to dev.
  * Fix typo in router rebuild call. (#2398)
  * Fix #1945: Allow equal sign in additional form value arguments. (#2401)
  * drush cr sets a request method (#2393)
  * Fix #2405. Handle exception when determining home dir.
  * Fix #2394 drush_is_windows().
  * Fix notice about unknown annotationdata variable.
  * Fix notice about missing index names in annotationcommand_adapter_command_names().
  * Fix #2399. Show how to save make-convert output to a file.
  * Prep for 8.1.7
* Fri Oct 14 2016 jimmy@boombatower.com
- Update to version 8.1.6:
  * Back to dev.
  * Backport Composer support into make-convert command (#2368)
  * Fix #2369. Update drush dependency phpdocumentor/reflection-docblock to 2.x
  * Update to Annotated Commands 2.0.0-rc3.
  * Update to new construction requirements for FormatterManager(), and get the array from the AnnotationData object prior to passing it to FormatterOptions.
  * Update to annotated commands rc6, and add the example:table and druplicon hook, so we can start to work on getting those to work here.
  * Display options added by hooks in help. Hooks are not called yet.
  * Validate options added by hooks, so an error is not returned if a user supplies such an option on the commandline.  Hook functions still are not called, though.
  * Remove the old druplicon. Call the post-command hook from the annotated Druplicon command to print the Druplicon when requested.
  * Appropriately set default option values for options added by hooks.
  * Update to latest annotated command hook APIs.
  * We need to put the command name back onto the head of the arguments in the DrushInputAdapter constructor.
  * Update to annotated-command 2.0.0-rc7 and output-formatters 2.0.0-rc3 (same code, but tagged).
  * Avoid the prompt when using --config-dir during site-install.
  * Remove unnecessary (optional) $ from @option annotations.
  * Fill in the function bodies for the other hook functions.
  * Update to stable releases of annotated-command and output-formatters.
  * Fix #2364. Source and target databases are the same while port numbers differ.
  * Fix typo.
  * Fix yaml makefile generation - reading looks for patch, not patches. (#2351)
  * Add some docblock comments to annotationcommand_adapter.inc.
  * Fix typo when using --config-dir during site-install. Fix #2375.
  * Fix #2379. Canonicalize root in site alias record.
  * Improve path handling in prepare_backup_dir() method and all that it calls into.
  * One more path join improvement.
  * Fix #2379. drush_is_windows() no longer accepted an  parameter.
  * Remove confusing docs from aliases example. Fixes #1155.
  * Fix composer branch-alias constraint (#2392) in make-convert
  * Fix(bootstrap): Do not clear the module_implements() cache on a drush invocation (#2386)
  * FIX: Database is now created when containing a dash (#2349)
  * Fix #2372. drush status: Database: Connected was dropped
  * Assure that dt() emits a string, even on bootstrapped D8 sites.
  * Fix #2363. Remove deprecated text from example.bashrc
  * Prep for 8.1.6
* Mon Sep 26 2016 jimmy@boombatower.com
- Update to version 8.1.5:
  * Back to dev.
  * drush.phar was trying to find launcher.
  * Prep for 8.1.5
* Sun Sep 25 2016 jimmy@boombatower.com
- Update to version 8.1.4:
  * Provide annoted command support for Drush 8.
  * Fix up help output for annotated commands.
  * Ensure that options are passed to the command.
  * Add tests for annotated commands.
  * Better handling and testing of help for annotation commands.
  * Cache annotated commandfile discovery results.
  * Disable the woot module to avoid cross-contamination of the Drupal test site's database.
  * Be a little more robust about disappearing annotation command files.
  * Support ignored-modules for annotated commands.
  * Extract consolidation/annotated-command classes out for backport, to avoid dependency on Symfony/Console.
  * Annotated commands tests for Drupal 6.
  * Fix CommandInfo for php 5.4.
  * Add consolidation/output-formatters.
  * Use consolidation/output-formatters with annotated commands, and update to use actual consolidation/annotated-command project.
  * Update to annotated comands 1.0.0-beta8, and add a test for backend results from annotated commands.
  * Factor annotationcommand_adapter_get_commands_for_commandhandler out of annotationcommand_adapter_get_commands.
  * Use modules' services file to find commandfile instances.
  * Do a full bootstrap when running help, to ensure that the module service commands are found.
  * Require a @command annotation for module service command methods, but do not require it for internal command handlers.
  * Back to dev.
  * Merge pull request #1876 from matthijs-va/make-update-fixed-core
  * Do command discovery via tagged services rather than service parameters.
  * Support --ignored-modules in tagged services.
  * Check to see if DrupalKernel::addServiceModifier already exists; if so, use the provided createFromRequest method.
  * Update to consolidation/annotated-command 1.0.0-beta11.
  * Support symfony console commands. Note that we call Command::run() directly; we do not use an Application object.
  * Do not rebuild the container; it does not appear to be necessary, and it causes problems.
  * Get rid of unnecessary cleanup in annotated command test.
  * Add tests for Symfony Console commands and annotated Symfony Console commands.
  * Taking rebuild container out just caused other problems; perhaps $kernel->invalidateContainer() will do the trick.
  * Update to consolidation/output-formatters 1.0.0-beta6
  * Remove dead code. Use drush init instead.
  * Fix #2176. Remove dependency on config module for config-import.
  * Fix make tests, deprecate SVN support.
  * Partial revert to fix make tests.
  * Fixed #2054: Document 'do_recursion' option in Drush Make.
  * Fixes #2189: Support 'no-core' tarballs for profile downloads.
  * Add docs for 'variant' project parameter for Drush Make.
  * Don't recurse when we're using a pre-built profile tarball.
  * Fix fatal error when using --db-prefix (#2178)
  * Mention --user defaults to 0 (#2201)
  * Fix #2198 - fix pointer regarding Composer.
  * Test with devel-reinstall instead of devel-download.
  * Maintain compatibility with Drush extensions (e.g. drush_ctex_bonus) that use DRUSH_LOG_CALLBACK.
  * Change sendmail_path to match drupal-composer. Hope this is more reliable.
  * Fix issue with included makefile on git repo. (#2238)
  * Fox typo.
  * Add a new config-delete command. Useful for developers.
  * Fox another type and remove old code comment.
  * Fox typo in code comment.
  * Fixes #2258 : Disable automated cron on drush requests (#2259)
  * Changed single quotes to double quotes in extra parameters (Sqlpgsql::$query_extra) for psql queries under windows. (#2252)
  * 'Sanitize query failed' with 'sqlsan --sanitize-password=no' on D8 (#2251)
  * Unish will now use latest relese of Drupal 8, not tip of 8.0.x
  * Fix #2257 config-pull gets cancelled with no helpful error message.
  * Fix #2270. Don't show a warning for Requirements that are just INFO. The fix here also starts showing a warning when we previously did not. This affects updatedb command and nothing else AFAIK.
  * Oops - bad equals sign.
  * Fix make tests to not rely on sourceforge (#2269)
  * Fix #2219. twig-compile should find templates in all active themes.
  * Try to speed up builds by directory caching at Travis.
  * Fixed method signature in DrupalKernel. (#2202)
  * Adds sub-options for xhprof_enable() flags. (#2174)
  * Fix #2277 pm-download puts drush commands in wrong location.
  * Prep for 8.1.3.
  * Back to dev
  * Fix #2287 and #1581. Warn about risks of using --no-backup option during pm-updatecode and pm-update commands.
  * Fix #2110 and #2111 - Always return value from ->drop() method.
  * Fix SQL hostname for localhost #2017 Also fixes missing error handling
  * Test project versions are checked strictly (no numeric equivalence).
  * Use string comparison for release versions.
  * Fixed condition for hidden files.
  * Fix drush_is_nested_directory() and drush_preflight_command_dispatch() on Windows by using DIRECTORY_SEPARATOR.
  * Use DIRECTORY_SEPARATOR in startup.inc. (#2300)
  * Get rid of Drush's own drush.bat.
  * Fix #2302 - dont delete .htaccess during config-pull.
  * Fix #2246. Can't make requests from same dir as drush.phar when renamed to 'drush' per install instructions.
  * Fix #2246 by moving check for Phar discovery during startup.
  * Fix #2210 Ignore .idea dir in git.
  * fix typo in docs.
  * download theme engines into the sensible default place for theme engines from "contrib"
  * Fix drush_backend_invoke_concurrent() thinks @self is a different site
  * Skip the launcher when using Windows. (#2312)
  * Double quotes around  as it can contain spaces.
  * Some enhancements to Finder and misc Unish fixes for Windows.
  * Specify event-dispatcher in composer.json in order to get a Drupal compatible version. Trying to get tests back to green on this 8.x branch.
  * Specify PHP 5.4 as platform requirement in composer.json. See https://seld.be/notes/new-composer-patterns.
  * Issue #2320: Fixing typo in includes/preflight.inc. (#2321)
  * Fix #2318. Set cwd when Finder is launching via proc_open().
  * Add updb option to sync_enable example. (#2247)
  * Handle requeue exception in 8.x (#2323)
  * Progress on Appveyor testing. Still lots of fails.
  * A few test fixes for Windows.
  * Add unish.bat for easier testing on Windows.
  * Merge pull request #2330 from drush-ops/fix-make-tests2
  * A few Windows related fixes.
  * Fix escaping in testDispatchStrictOptions.
  * use stdin in test.
  * Break up testReleaseNotes for better Windows compat.
  * No fork test on Windows.
  * Appveyor tweak for testMakeBZ2.
  * Bit_bucket fix for Windows.
  * A bit of work on testDrushFinder() for Windows compat.
  * Canonicalize paths for testCommandVersionSpecific().
  * Windows test tweaks.
  * Fix #1788. Remove winrs support.
  * Parse error fix.
  * Skip complete test on Windows.
  * Fix expectation for drush-script.
  * Skip end of testDispatchStrictOptions() for Windows.
  * Simplify \Unish\drushScriptCase::getDrushLocation.
  * Canonicalize the /path/to/drush.
  * standardize etc_drush path in test.
  * Canonicalize our expected path to drush.php in test.
  * Remove Unish\outputFormatCase::testOutputFormatWithDrupal as it is superceded by \Unish\outputFormatUnitCase.
  * Uncomment 'Double up percents.' during Windows argument escaping in Unish.
  * Undo double percents. Did not help.
  * Handle FALSE in drush_find_drush().
  * Make a copy of the test fixture WootCommands, so that the Drupal 7 module and the Drupal 8 module each has their own version.
  * Try explicitly clearing the Drush commandfile cache.
  * The backslash at the beginning of the classname in @return statements is now very important, as the namespace of the file is respected by the doc block parser.
  * Add a sanity-check assert to the woot commands test.
  * Updated composer.lock, and a few more asserts, to see the first directory that did not get copied.
  * Add some error checking in the recursive_copy function.
  * Only use recursive_copy in annotatedCommandTest on Windows.
  * Update annotated command test for Drupal 6.
  * Discover Drush's own annotated commands and convert browse to an annotated command.
  * Get latest consolidation/* packages
  * Fix annotationcommand_adapter_process_command() for the case where the args array is empty.
  * Add support for @bootstrap and @handle-remote-commands annotations. Needs docs.
  * Composer.lock changes. Keeps PHP 5.4 compat.
  * Add argument completion for annotated commands.
  * Fix 2302 .htaccess getting removed during config-pull.
  * Update URL to search for Drush packages on Packagist.
  * Prep for 8.1.4
* Thu May  5 2016 jimmy@boombatower.com
- Update to 8.1.2.
  https://github.com/drush-ops/drush/releases/tag/8.1.2
* Wed May  4 2016 jimmy@boombatower.com
- Update to 8.1.1.
  https://github.com/drush-ops/drush/releases/tag/8.1.1
* Tue Apr 26 2016 jimmy@boombatower.com
- Update to 8.1.0.
  https://github.com/drush-ops/drush/releases/tag/8.1.0
- Update extensions.php to remove deprecated composer info -i flag.
* Tue Mar 15 2016 jimmy@boombatower.com
- Split out locally built vendor directory into separate tarball.
* Wed Mar  9 2016 jimmy@boombatower.com
- Update to 8.0.5.
  https://github.com/drush-ops/drush/releases/tag/8.0.5
* Fri Feb  5 2016 jimmy@boombatower.com
- Update to 8.0.3.
  https://github.com/drush-ops/drush/releases/tag/8.0.3
* Sun Jan 10 2016 jimmy@boombatower.com
- Update to 8.0.2.
  https://github.com/drush-ops/drush/releases/tag/8.0.2
- Fix spelling of licenses.txt.
- Increase php min to 5.5.9, based on composer extensions.txt.
* Wed Dec  9 2015 jimmy@boombatower.com
- Change php5 requirement to php since it already has version and
  thus allows for php7 to fulfill requirement.
* Sun Nov 29 2015 jimmy@boombatower.com
- Update to 8.0.1.
  https://github.com/drush-ops/drush/releases/tag/8.0.1
* Sat Nov 21 2015 jimmy@boombatower.com
- spec-cleaner
* Sat Nov 21 2015 jimmy@boombatower.com
- Update to 8.0.0.
  https://github.com/drush-ops/drush/releases/tag/8.0.0
* Fri Mar 27 2015 jimmy@boombatower.com
- Update to 6.6.0.
* Tue Nov 18 2014 jimmy@boombatower.com
- Update to 6.5.0.
* Sat Nov  1 2014 jimmy@boombatower.com
- Update to 6.4.0.
- Remove unnecessary executable bit from drush/lib.
- Simplify package build and install instructions.
* Wed Nov 13 2013 jimmy@boombatower.com
- Update to 6.1.0.
- Update youngj-httpserver to 1.0.0.
* Wed Nov 13 2013 jimmy@boombatower.com
- Update to 5.10.
* Thu Apr 18 2013 jimmy@boombatower.com
- Update to 5.9.
* Tue Nov 13 2012 jimmy@boombatower.com
- Update to 5.8.
* Sat Aug 18 2012 jimmy@boombatower.com
- Update to 5.7.
* Fri Aug 10 2012 jimmy@boombatower.com
- Update to 5.6.
- Customize drush update message for zypper installation.
* Thu Aug  9 2012 jimmy@boombatower.com
- Update to 5.5.
* Mon Jun  4 2012 jimmy@boombatower.com
- Update to 5.4.
* Sat May 26 2012 jimmy@boombatower.com
- Update to 5.3.
* Mon May 21 2012 jimmy@boombatower.com
- Update to 5.2.
- Add Provides for drush_make.
* Thu Apr  5 2012 jimmy@boombatower.com
- Update to 5.1.
* Sat Mar 24 2012 jimmy@boombatower.com
- Update to 5.0.
- Install bash complete script.
- Add obsoletes drush_make.
- Update Console_Table and convert to 5.x installation location.
- Add youngj-httpserver for built in server command.
* Mon Aug 15 2011 jimmy@boombatower.com
- Update to 4.5.
- Include PEAR Console_Table as a seperate source item.
- Remove macros where they are unnecessary.
- Remove cvs requirement.
- Remove .gitignore files.
- Correct summary build warnings.
